@@ -129,8 +129,8 @@ function tw_google_language_tools
 		"en-zt") TW_LANGUAGE="en|zh_TW";;
 		*) TW_LANGUAGE=$(printf ${1##*.} | tr '-' '|');;
 	esac
-	TW_TERM="$2"
-	curl -s -A "Mozilla/5.0" -d "hl=en" -d "ie=UTF8" -d "text=${TW_TERM}" -d "langpair=${TW_LANGUAGE}" http://translate.google.com/translate_t | grep "gtrans" | gawk -F"gtrans" '{print $2}' | cut -d'"' -f2
+	TW_TERM=$2
+	curl -s -A "Mozilla/5.0" -d "hl=en" -d "ie=UTF8" -d "text=${TW_TERM}" -d "langpair=${TW_LANGUAGE}" http://translate.google.com/translate_t | grep "gtrans" | gawk -F"gtrans" '{print $2}' | cut -d'"' -f2 | links -dump | links -dump | sed -e 's/^[[:space:]]*//'
 }
 
 function tw_ls_dictionaries_google_language_tools
